@@ -192,7 +192,9 @@ use lib "/export/scratch/programs/lib/site_perl/5.8.7/";
 use UMLS::Interface;
 use Getopt::Long;
 
-GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "measure=s", "config=s", "infile=s", "dbfile=s", "precision=s", "info", "allsenses", "forcerun", "verbose");
+eval(GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "measure=s", "config=s", "infile=s", "dbfile=s", "precision=s", "info", "allsenses", "forcerun", "verbose")) or die ("Please check 
+the above mentioned option(s).\n");
+
 
 my $debug = 0;
 
@@ -435,7 +437,7 @@ sub loadMeasures {
     my $meas;
 
     if($measure eq "vector") {
-	require "UMLS::Similarity::vector";
+	require "UMLS/Similarity/vector.pm";
 	$meas = UMLS::Similarity::vector->new($umls, $opt_dbfile)
     }
     #  load the module implementing the Leacock and 
@@ -713,7 +715,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: umls-similarity.pl,v 1.2 2009/11/03 20:08:32 btmcinnes Exp $';
+    print '$Id: umls-similarity.pl,v 1.3 2009/11/03 20:56:54 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
